require 'faraday'
require 'faraday_middleware'

module BaiduLBS
  module Request
    def get(path, params = {}, options = {})
      request(:get, path, params, options)
    end

    def post(path, params = {}, options = {})
      request(:post, path, params, options)
    end

    def request(method, path, params, options)
      params[:ak] = BaiduLBS.ak unless params[:ak]

      response = connection(options).send(method) do |request|
        case method
        when :get, :delete
          request.url(path, params)
        when :post, :put
          request.path = path
          request.body = params
        end
      end
      response.body
    end

    def connection(options)
      connection = Faraday.new(url: BaiduLBS.api_endpoint) do |builder|
        builder.request :multipart if options[:multipart]
        builder.request :url_encoded
        builder.use FaradayMiddleware::ParseJson
        builder.adapter Faraday.default_adapter
      end
      connection
    end
  end
end
